% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/log_normal.R
\name{log_normal_variance_one_sample}
\alias{log_normal_variance_one_sample}
\title{Test the variance of a log normal distribution.}
\source{
\itemize{
\item \url{https://en.wikipedia.org/wiki/Likelihood-ratio_test}
\item Yudi Pawitan. In All Likelihood. Oxford University Press.
\item Hodd, McKean, and Craig. Introduction to Mathematical Statistics. Pearson.
}
}
\usage{
log_normal_variance_one_sample(
  x,
  sigma.squared,
  alternative = "two.sided",
  conf.level = 0.95
)
}
\arguments{
\item{x}{a numeric vector of data.}

\item{sigma.squared}{a number indicating the tested value of sigma squared.}

\item{alternative}{a character string specifying the alternative hypothesis, must be one of "two.sided" (default), "greater" or "less".}

\item{conf.level}{confidence level of the likelihood interval.}
}
\value{
An S3 class containing the test statistic, p value, likelihood based confidence interval, and alternative
hypothesis.
}
\description{
Test the variance of a log normal distribution.
}
\examples{
library(LRTesteR)

# Null is true
set.seed(1)
x <- rlnorm(100, 0, 1)
log_normal_variance_one_sample(x, 1, "two.sided")

# Null is false
set.seed(1)
x <- rlnorm(100, 0, 2)
log_normal_variance_one_sample(x, 1, "greater")
}
